Package: shinydashboardPlus
Type: Package
Title: Add More 'AdminLTE2' Components to 'shinydashboard'
Version: 2.0.6
Authors@R: c(
  person("David", "Granjon", email = "dgranjon@ymail.com", role = c("aut", "cre")),
  person(family = "RinteRface", role = "cph"),
  person(family = "Almasaeed Studio", role = c("ctb", "cph"), comment = "AdminLTE2 theme for Bootstrap 3"),
  person("Guang", "Yang", role = c("ctb", "cph"), comment = "ygdashboard original template"),
  person("Winston", "Chang", role = c("ctb", "cph"), comment = "Functions from shinydashboard"),
  person("Victor", "Perrier", email = "victor.perrier@dreamrs.fr", role = "ctb",
          comment = "improved the shinydashboardPlusGallery"))
Maintainer: David Granjon <dgranjon@ymail.com>
Description: Extend 'shinydashboard' with 'AdminLTE2' components. 
             'AdminLTE2' is a free 'Bootstrap 3' dashboard template available
             at <https://adminlte.io>. Customize boxes, add timelines and a lot more. 
License: GPL (>= 2) | file LICENSE
Imports: shiny, htmltools, shinydashboard, fresh, waiter (>= 0.2.3),
        lifecycle
Suggests: styler (>= 1.2.0), shinyAce, shinyWidgets, shinyEffects,
        shinyjqui, knitr, rmarkdown, jsonlite, bslib
URL: https://github.com/RinteRface/shinydashboardPlus,
        https://shinydashboardPlus.rinterface.com/
BugReports: https://github.com/RinteRface/shinydashboardPlus/issues
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
RdMacros: lifecycle
NeedsCompilation: no
Packaged: 2025-08-25 12:03:29 UTC; davidgranjon
Author: David Granjon [aut, cre],
  RinteRface [cph],
  Almasaeed Studio [ctb, cph] (AdminLTE2 theme for Bootstrap 3),
  Guang Yang [ctb, cph] (ygdashboard original template),
  Winston Chang [ctb, cph] (Functions from shinydashboard),
  Victor Perrier [ctb] (improved the shinydashboardPlusGallery)
Repository: CRAN
Date/Publication: 2025-08-25 12:40:07 UTC
Built: R 4.6.0; ; 2026-04-28 13:36:40 UTC; unix
