# Load packages
library(shiny)
library(shinyjqui)
library(shinydashboard)
library(shinyWidgets)
library(shinydashboardPlus)
library(shinyAce)
library(styler)
library(shinyEffects)

# tabs
source("boxes/close_box.R")
source("boxes/label_box.R")
source("boxes/widget_user_box.R")
source("boxes/social_box.R")
source("boxes/flip_box.R")
source("boxes/boxes_tab.R")
source("buttons/app_buttons.R")
source("buttons/social_buttons.R")
source("buttons/buttons_tab.R")

source("box_elements/box_sidebar.R")
source("box_elements/description_block.R")
source("box_elements/box_pad.R")
source("box_elements/user_list.R")
source("box_elements/nav_pills.R")
source("box_elements/product_list.R")
source("box_elements/accordion.R")
source("box_elements/todo_list.R")
source("box_elements/timeline.R")
source("box_elements/box_profile.R")
source("box_elements/user_post.R")
source("box_elements/user_messages.R")
source("box_elements/box_elements_tab.R")

source("extra_elements/vertical_progress.R")
source("extra_elements/carousels.R")
source("extra_elements/extra_elements_tab.R")
