box_profile <- 'box(
  title = "Box with profile",
  width = 12,
  status = "primary",
  boxProfile(
    image = "https://adminlte.io/themes/AdminLTE/dist/img/user4-128x128.jpg",
    title = "Nina Mcintire",
    subtitle = "Software Engineer",
    bordered = TRUE,
    boxProfileItem(
      title = "Followers",
      description = 1322
    ),
    boxProfileItem(
      title = "Following",
      description = 543
    ),
    boxProfileItem(
      title = "Friends",
      description = 13287
    )
  )
)'
