product_list <- 'box(
  title = "Product List",
  status = "primary",
  width = 12,
  productList(
    productListItem(
      image = "https://www.pngmart.com/files/1/Haier-TV-PNG.png", 
      title = "Samsung TV", 
      subtitle = "$1800", 
      color = "yellow",
      "This is an amazing TV, but I do not like TV!"
    ),
    productListItem(
      image = "https://upload.wikimedia.org/wikipedia/commons/7/77/IMac_Pro.svg", 
      title = "Imac 27", 
      subtitle = "$4999", 
      color = "red",
      "This is were I spend most of my time!"
    )
  )
)'
