widget_user_box1 <- 'userBox(
  width = 12,
  title = userDescription(
    title = "Nadia Carmichael",
    subtitle = "lead Developer",
    type = 2,
    image = "https://adminlte.io/themes/AdminLTE/dist/img/user7-128x128.jpg",
  ),
  status = "warning",
  "Some text here!",
  footer = "The footer here!"
)'

widget_user_box2 <- 'userBox(
  width = 12,
  title = userDescription(
    title = "Alexander Pierce",
    subtitle = "Founder & CEO",
    type = 1,
    image = "https://adminlte.io/themes/AdminLTE/dist/img/user1-128x128.jpg",
  ),
  status = "purple",
  closable = TRUE,
  "Some text here!",
  footer = "The footer here!"
)'


widget_user_box3 <- 'userBox(
  width = 12,
  title = userDescription(
    title = "Elizabeth Pierce",
    subtitle = "Web Designer",
    image = "https://adminlte.io/themes/AdminLTE/dist/img/user3-128x128.jpg",
    backgroundImage = "https://cdn.statically.io/img/wallpaperaccess.com/full/1119564.jpg",
  ),
  status = "teal",
  closable = TRUE,
  maximizable = TRUE,
  "Some text here!",
  footer = "The footer here!"
)'
