user_list <- 'box(
  title = "User List example",
  status = "success",
  width = 12,
  userList(
    userListItem(
      image = "https://www.rstudio.com/wp-content/uploads/2014/04/shiny.png", 
      title = "Shiny", 
      subtitle = "28.04.2018"
    ),
    userListItem(
      image = "https://www.rstudio.com/wp-content/uploads/2014/04/knitr.png", 
      title = "knitr", 
      subtitle = "28.04.2018"
    ),
    userListItem(
      image = "https://www.rstudio.com/wp-content/uploads/2017/05/rmarkdown.png", 
      title = "Rmarkdown", 
      subtitle = "28.04.2018"
    )
  )
)'
